==> openGion7.2.9.4_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*   1 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                                     NOT NULL            /*   2 予約番号     */
 , EXECID       varchar           (   20 )                  NOT NULL            /*   3 処理ID       */
 , FGTKAN       varchar           (    1 )      DEFAULT '2' NOT NULL            /*   4 取込完了ﾌﾗｸﾞ */
 , TMSTR        varchar           (   14 )                  NOT NULL            /*   5 開始時刻     */
 , TMEND        varchar           (   14 )                                      /*   6 完了時刻     */
 , FILE_IN      varchar           (  255 )                                      /*   7 ﾌｧｲﾙ取込     */
 , FILE_OK      varchar           (  255 )                                      /*   8 処理済OKﾌｧｲﾙ */
 , FILE_NG      varchar           (  255 )                                      /*   9 処理済NGﾌｧｲﾙ */
 , SUTORI       INTEGER                                     NOT NULL            /*  10 取込件数     */
 , ERRMSG       varchar           ( 4000 )                                      /*  11 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE71S.sql <==
/****************************************************************************/
/* GE71 ( 取込実績ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE71 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*   1 ｼｽﾃﾑID       */
 , RSRV_NO      INTEGER                                     NOT NULL            /*   2 予約番号     */
 , EXECID       varchar           (   20 )                  NOT NULL            /*   3 処理ID       */
 , FGTKAN       varchar           (    1 )      DEFAULT '2' NOT NULL            /*   4 取込完了ﾌﾗｸﾞ */
 , TMSTR        varchar           (   14 )                  NOT NULL            /*   5 開始時刻     */
 , TMEND        varchar           (   14 )                                      /*   6 完了時刻     */
 , FILE_IN      varchar           (  255 )                                      /*   7 ﾌｧｲﾙ取込     */
 , FILE_OK      varchar           (  255 )                                      /*   8 処理済OKﾌｧｲﾙ */
 , FILE_NG      varchar           (  255 )                                      /*   9 処理済NGﾌｧｲﾙ */
 , SUTORI       INTEGER                                     NOT NULL            /*  10 取込件数     */
 , ERRMSG       varchar           ( 4000 )                                      /*  11 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
